@@ -29,9 +29,10 @@
 
 #ifndef _IOKIT_IOFireWireLink_H
 #define _IOKIT_IOFireWireLink_H
-#include <IOKit/IOService.h>
-#include <IOKit/IOFilterInterruptEventSource.h>
-#include <IOKit/firewire/IOFireWireController.h>
+
+#import <IOKit/IOService.h>
+#import <IOKit/IOFilterInterruptEventSource.h>
+#import <IOKit/firewire/IOFireWireController.h>
 
 enum
 {
@@ -101,74 +102,94 @@ public:
     // Set power state
     virtual IOReturn setLinkPowerState ( unsigned long powerStateOrdinal) = 0;
 
-    // Bus management stuff
-    virtual IOReturn setContender(bool state) = 0;
-    virtual IOReturn setRootHoldOff(bool state) = 0;
-    virtual IOReturn setCycleMaster(bool state) = 0;
-    
-    virtual IODCLProgram *createDCLProgram(bool talking, DCLCommandStruct *opcodes,
-            IOFireWireController::DCLTaskInfo *info, UInt32 startEvent, UInt32 startState, UInt32 startMask) = 0;
+	// Bus management stuff
+	virtual IOReturn 				setContender(bool state) = 0;
+	virtual IOReturn 				setRootHoldOff(bool state) = 0;
+	virtual IOReturn 				setCycleMaster(bool state) = 0;
+	
+	virtual IODCLProgram*			createDCLProgram(bool talking, DCLCommand *opcodes,
+											IOFireWireController::DCLTaskInfo *info, UInt32 startEvent, 
+											UInt32 startState, UInt32 startMask) = 0;
 
-    // Send a PHY packet
-    virtual IOReturn sendPHYPacket(UInt32 quad) = 0;
- 
-    // Check for hardware interrupts (typically from a timeout call)
-    virtual void handleInterrupts(int count) = 0;
+	// Send a PHY packet
+	virtual IOReturn 				sendPHYPacket(UInt32 quad) = 0;
 
-    virtual IOReturn resetBus() = 0;
-    virtual IOReturn asyncRead(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo, 
-				int speed, int label, int size, IOFWAsyncCommand *cmd) = 0;
-    virtual IOReturn asyncReadQuadResponse(UInt16 nodeID, int speed, 
-					int label, int rcode, UInt32 data) = 0;
-    virtual IOReturn asyncReadResponse(UInt16 nodeID, int speed,
-                                       int label, int rcode, IOMemoryDescriptor *buf,
-				       IOByteCount offset, int len) = 0;
+	// Check for hardware interrupts (typically from a timeout call)
+	virtual void 					handleInterrupts(int count) = 0;
 
-    virtual IOReturn asyncWrite(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo,
-		int speed, int label, IOMemoryDescriptor *buf, IOByteCount offset,
-		int size, IOFWAsyncCommand *cmd) = 0;
-    virtual IOReturn asyncWrite(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo,
-                                int speed, int label, void *data, int size, IOFWAsyncCommand *cmd) = 0;
-    virtual IOReturn asyncWriteResponse(UInt16 nodeID, int speed, 
-					int label, int rcode, UInt16 addrHi) = 0;
+	virtual IOReturn 				resetBus() = 0;
+	virtual IOReturn 				asyncRead(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo, 
+											int speed, int label, int size, IOFWAsyncCommand *cmd) = 0;
+	virtual IOReturn 				asyncReadQuadResponse(UInt16 nodeID, int speed, 
+											int label, int rcode, UInt32 data) = 0;
+	virtual IOReturn				asyncReadResponse(UInt16 nodeID, int speed,
+										int label, int rcode, IOMemoryDescriptor *buf,
+										IOByteCount offset, int len) = 0;
+	virtual IOReturn				asyncWrite(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo,
+											int speed, int label, IOMemoryDescriptor *buf, IOByteCount offset,
+											int size, IOFWAsyncCommand *cmd) = 0;
+	virtual IOReturn 				asyncWrite(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo,
+											int speed, int label, void *data, int size, IOFWAsyncCommand *cmd) = 0;
+	virtual IOReturn 				asyncWriteResponse(UInt16 nodeID, int speed, 
+											int label, int rcode, UInt16 addrHi) = 0;
+	virtual IOReturn 				asyncLock(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo, 
+											int speed, int label, int type, void *data, int size, IOFWAsyncCommand *cmd) = 0;
+	virtual IOReturn 				asyncLockResponse(UInt16 nodeID, int speed, 
+											int label, int rcode, int type, void *data, int len) = 0;
 
-    virtual IOReturn asyncLock(UInt16 nodeID, UInt16 addrHi, UInt32 addrLo, 
-			int speed, int label, int type, void *data, int size, IOFWAsyncCommand *cmd) = 0;
-    virtual IOReturn asyncLockResponse(UInt16 nodeID, int speed, 
-				int label, int rcode, int type, void *data, int len) = 0;
+	// Try to fix whatever might have caused the other device to not respond
+	virtual IOReturn 				handleAsyncTimeout(IOFWAsyncCommand *cmd) = 0;
 
-    // Try to fix whatever might have caused the other device to not respond
-    virtual IOReturn handleAsyncTimeout(IOFWAsyncCommand *cmd) = 0;
+	// Local ConfigROM changed
+	// Bus will be reset (via resetBus()) if this returns kIOReturnSuccess
+	virtual IOReturn 				updateROM(const OSData *rom) = 0;
+	
+	// Read Cycle time register. safe to call at any time.
+	virtual IOReturn 				getCycleTime(UInt32 &cycleTime) = 0;
+	virtual IOReturn 				getBusCycleTime(UInt32 &busTime, UInt32 &cycleTime) = 0;
+	virtual IOReturn 				setBusTime(UInt32 busTime) = 0;
 
-    // Local ConfigROM changed
-    // Bus will be reset (via resetBus()) if this returns kIOReturnSuccess
-    virtual IOReturn updateROM(const OSData *rom) = 0;
-    
-    // Read Cycle time register. safe to call at any time.
-    virtual IOReturn getCycleTime(UInt32 &cycleTime) = 0;
-    virtual IOReturn getBusCycleTime(UInt32 &busTime, UInt32 &cycleTime) = 0;
-    virtual IOReturn setBusTime(UInt32 busTime) = 0;
+	virtual CSRNodeUniqueID 		getGUID() = 0;
+	virtual UInt32 					getBusCharacteristics() = 0;
+	virtual UInt32 					getMaxSendLog() = 0;
+	virtual UInt16 					getNodeID() = 0;
 
-    virtual CSRNodeUniqueID getGUID() = 0;
-    virtual UInt32 getBusCharacteristics() = 0;
-    virtual UInt32 getMaxSendLog() = 0;
-    virtual UInt16 getNodeID() = 0;
-
-    virtual IOFireWireController * getController() const;
-    
-    // Implement IOService::getWorkLoop
-    virtual IOWorkLoop *	getWorkLoop() const;
-    
-    // FireWire wants an IOFWWorkLoop
-    virtual IOFWWorkLoop *	getFireWireWorkLoop() const;
-    
-    virtual void 			setNodeIDPhysicalFilter( UInt16 nodeID, bool state ) =0;
-	virtual void 			setNodeFlags( UInt16 nodeID, UInt32 flags )=0;
+	virtual IOFireWireController * 	getController() const;
+	
+	// Implement IOService::getWorkLoop
+	virtual IOWorkLoop *			getWorkLoop() const;
+	
+	// FireWire wants an IOFWWorkLoop
+	virtual IOFWWorkLoop *			getFireWireWorkLoop() const;
+	
+	virtual void 					setNodeIDPhysicalFilter( UInt16 nodeID, bool state ) = 0;
+	virtual void 					setNodeFlags( UInt16 nodeID, UInt32 flags ) = 0;
 	
 	// don't forget about the isoch workloop:
 	virtual void			closeIsochGate() ;
 	virtual void			openIsochGate() ;
 	
+	virtual	IOReturn asyncStreamTransmit(
+														UInt32					channel,
+														int						speed,		
+														UInt32					sync,
+														UInt32					tag,
+														void					* buf,		
+														int						len,
+														IOFWAsyncStreamCommand 	* cmd ) = 0;
+
+	virtual	IOReturn asyncStreamTransmit(
+														UInt32					channel,
+														int						speed,		
+														UInt32					sync,
+														UInt32					tag,
+														IOMemoryDescriptor		*pmd,
+														IOByteCount				offset,
+														int						length,
+														IOFWAsyncStreamCommand	* cmd ) = 0;
+
+	virtual void setSecurityMode( IOFWSecurityMode mode ) = 0;
+	
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireLink, 0);
     OSMetaClassDeclareReservedUnused(IOFireWireLink, 1);
